@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals, print_function
 
 from ..plugins import SoCoPlugin
 
@@ -22,7 +23,7 @@ class ExamplePlugin(SoCoPlugin):
 
     @property
     def name(self):
-        return u'Example Plugin for {name}'.format(name=self.username)
+        return 'Example Plugin for {name}'.format(name=self.username)
 
     def music_plugin_play(self):
         """ Play some music
@@ -30,15 +31,12 @@ class ExamplePlugin(SoCoPlugin):
         This is just a reimplementation of the ordinary play function, to show
         how we can use the general upnp methods from soco """
 
-        print 'Hi,', self.username
+        print('Hi,', self.username)
 
-        response = self.soco.send_command(
-            TRANSPORT_ENDPOINT, PLUGIN_PLAY_ACTION, PLUGIN_PLAY_BODY)
-
-        if (response == PLUGIN_PLAY_RESPONSE):
-            return True
-        else:
-            return self.soco.parse_error(response)
+        self.soco.avTransport.Play([
+            ('InstanceID', 0),
+            ('Speed', 1)
+            ])
 
     def music_plugin_stop(self):
         """ Stop the music
@@ -46,23 +44,5 @@ class ExamplePlugin(SoCoPlugin):
         This methods shows how, if we need it, we can use the soco
         functionality from inside the plugins """
 
-        print 'Bye,', self.username
+        print('Bye,', self.username)
         self.soco.stop()
-
-
-TRANSPORT_ENDPOINT = '/MediaRenderer/AVTransport/Control'
-PLUGIN_PLAY_ACTION = '"urn:schemas-upnp-org:service:AVTransport:1#Play"'
-PLUGIN_PLAY_BODY = '''
-<u:Play xmlns:u="urn:schemas-upnp-org:service:AVTransport:1">
-  <InstanceID>0</InstanceID>
-  <Speed>1</Speed>
-</u:Play>
-'''
-PLUGIN_PLAY_RESPONSE = '''
-<s:Envelope xmlns:s="http://schemas.xmlsoap.org/soap/envelope/"
- s:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
-  <s:Body>
-    <u:PlayResponse xmlns:u="urn:schemas-upnp-org:service:AVTransport:1">
-    </u:PlayResponse>
-  </s:Body>
-</s:Envelope>'''
